aboutsummaryrefslogtreecommitdiff
path: root/src/dogecoin.cpp
diff options
context:
space:
mode:
authorTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
committerTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
commite64843ced509c24f783276d4cc0f2f26c9d527f2 (patch)
tree7956d4ea416c5b3a531dbc6f356e1c9a643d9690 /src/dogecoin.cpp
parentreally s/doge/dis/g this time (diff)
downloaddiscoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.tar.xz
discoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.zip
really s/Doge/Dis/g this time
Diffstat (limited to 'src/dogecoin.cpp')
-rw-r--r--src/dogecoin.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/dogecoin.cpp b/src/dogecoin.cpp
index 560106396..b84c94d90 100644
--- a/src/dogecoin.cpp
+++ b/src/dogecoin.cpp
@@ -1,4 +1,4 @@
-// Copyright (c) 2015 The Dogecoin Core developers
+// Copyright (c) 2015 The Discoin Core developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
@@ -20,7 +20,7 @@ int static generateMTRandom(unsigned int s, int range)
return dist(gen);
}
// Dogecoin: Normally minimum difficulty blocks can only occur in between
// retarget blocks. However, once we introduce Digishield every block is
// a retarget, so we need to handle minimum difficulty on all blocks.
bool AllowDigishieldMinDifficultyForBlock(const CBlockIndex* pindexLast, const CBlockHeader *pblock, const Consensus::Params& params)
@@ -38,7 +38,7 @@ bool AllowDigishieldMinDifficultyForBlock(const CBlockIndex* pindexLast, const C
return (pblock->GetBlockTime() > pindexLast->GetBlockTime() + params.nPowTargetSpacing*2);
}
-unsigned int CalculateDogecoinNextWorkRequired(const CBlockIndex* pindexLast, int64_t nFirstBlockTime, const Consensus::Params& params)
+unsigned int CalculateDiscoinNextWorkRequired(const CBlockIndex* pindexLast, int64_t nFirstBlockTime, const Consensus::Params& params)
{
int nHeight = pindexLast->nHeight + 1;
const int64_t retargetTimespan = params.nPowTargetTimespan;
@@ -123,7 +123,7 @@ bool CheckAuxPowProofOfWork(const CBlockHeader& block, const Consensus::Params&
return true;
}
-CAmount GetDogecoinBlockSubsidy(int nHeight, const Consensus::Params& consensusParams, uint256 prevHash)
+CAmount GetDiscoinBlockSubsidy(int nHeight, const Consensus::Params& consensusParams, uint256 prevHash)
{
int halvings = nHeight / consensusParams.nSubsidyHalvingInterval;
@@ -20,7 +20,7 @@ int static generateMTRandom(unsigned int s, int range)
return dist(gen);
}
-// Dogecoin: Normally minimum difficulty blocks can only occur in between
+// Discoin: Normally minimum difficulty blocks can only occur in between
// retarget blocks. However, once we introduce Digishield every block is
// a retarget, so we need to handle minimum difficulty on all blocks.